@@ -17,7 +17,7 @@
 # Make sure comment recognition works in PROGRAMS.  Report from Mark
 # Galassi.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -30,5 +30,5 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-grep '^image_proc' Makefile.in && Exit 1
-Exit 0
+grep '^image_proc' Makefile.in && exit 1
+exit 0
