@@ -16,7 +16,7 @@
 
 # Make sure 'compile' is included when subdir-objects is used in a subdir.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat > configure.ac << END
 AC_INIT([$me], [1.0])
